@@ -127,5 +127,5 @@ class Stocket():
         self.token = token
 
     def dividends(self):
-        return requests.get(url + 'dividends', headers=headers, json={'token':self.token}).json()
+        return requests.get(url + 'dividends', headers=headers, json={'token':self.token}).json()['data']['recordsets'][0]
 
